@@ -60,7 +60,7 @@ struct _BonoboDockItemPrivate
 };
 
 GNOME_CLASS_BOILERPLATE (BonoboDockItem, bonobo_dock_item,
-			 GtkBin, GTK_TYPE_BIN);
+			 GtkBin, GTK_TYPE_BIN)
 
 enum {
   PROP_0,
@@ -81,11 +81,6 @@ enum {
   LAST_SIGNAL
 };
 
-/* this function is not public, but should be exported */
-void        bonobo_dock_item_set_behavior   (BonoboDockItem         *dock_item,
-                                             BonoboDockItemBehavior  behavior);
-
-
 static guint     get_preferred_width   (BonoboDockItem *item);
 static guint     get_preferred_height  (BonoboDockItem *item);
 
@@ -589,13 +584,11 @@ static void
 bonobo_dock_item_unrealize (GtkWidget *widget)
 {
   BonoboDockItem *di;
-  BonoboDockItemPrivate *priv;
 
   g_return_if_fail (widget != NULL);
   g_return_if_fail (BONOBO_IS_DOCK_ITEM (widget));
 
   di = BONOBO_DOCK_ITEM (widget);
-  priv = di->_priv;
 
   gdk_window_set_user_data (di->bin_window, NULL);
   gdk_window_destroy (di->bin_window);
@@ -820,11 +813,9 @@ bonobo_dock_item_size_allocate (GtkWidget     *widget,
 
   if (bin->child && GTK_WIDGET_VISIBLE (bin->child))
     {
-      GtkWidget *child;
       GtkAllocation child_allocation;
       int border_width;
 
-      child = bin->child;
       border_width = GTK_CONTAINER (widget)->border_width;
 
       child_allocation.x = border_width;
@@ -1177,8 +1168,7 @@ bonobo_dock_item_add (GtkContainer *container,
   /* Claim the base reference to the widget, so that it doesn't get owned by the
    * floating window.
    */
-  g_object_ref (widget);
-  gtk_object_sink (GTK_OBJECT (widget));
+  g_object_ref_sink (widget);
 
   gtk_widget_set_parent_window (widget, dock_item->bin_window);
   dock_item->_priv->child = widget;
@@ -1639,7 +1629,7 @@ bonobo_dock_item_detach (BonoboDockItem *item, gint x, gint y)
 
    */
 
-      gtk_container_add (GTK_CONTAINER (item->_priv->float_window), priv->float_window_box);
+      gtk_container_add (GTK_CONTAINER (priv->float_window), priv->float_window_box);
 
       widget = priv->grip; /* container_remove() will make priv->grip NULL, so we save it here */
       g_object_ref (priv->grip);
@@ -1656,16 +1646,18 @@ bonobo_dock_item_detach (BonoboDockItem *item, gint x, gint y)
       g_object_unref (priv->child);
     }
 
-  gtk_window_move (GTK_WINDOW (item->_priv->float_window), x, y);
-  gtk_widget_show_all (GTK_WIDGET (item->_priv->float_window));
+  gtk_window_move (GTK_WINDOW (priv->float_window), x, y);
+  gtk_widget_show_all (GTK_WIDGET (priv->float_window));
+
+  gdk_window_set_events (priv->float_window->window, gdk_window_get_events (priv->float_window->window) | GDK_BUTTON_PRESS_MASK);
 
   item->float_window_mapped = TRUE;
-  item->_priv->float_window_hidden = FALSE;
+  priv->float_window_hidden = FALSE;
 
   gdk_window_hide (GTK_WIDGET (item)->window);
   gtk_widget_queue_draw (GTK_WIDGET (item));
 
-  gtk_window_set_transient_for (GTK_WINDOW (item->_priv->float_window),
+  gtk_window_set_transient_for (GTK_WINDOW (priv->float_window),
                                 (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (item)))));
 
   g_signal_emit (item, dock_item_signals [DOCK_DETACH], 0);
