@@ -17,7 +17,7 @@
 GNOME_CLASS_BOILERPLATE (BonoboUIToolbarButtonItem,
 			 bonobo_ui_toolbar_button_item,
 			 GObject,
-			 bonobo_ui_toolbar_item_get_type ());
+			 bonobo_ui_toolbar_item_get_type ())
 
 /* Spacing between the icon and the label.  */
 #define SPACING 2
@@ -360,8 +360,6 @@ bonobo_ui_toolbar_button_item_construct (BonoboUIToolbarButtonItem *button_item,
 
 	gtk_button_set_relief (button_widget, GTK_RELIEF_NONE);
 
-/*	GTK_WIDGET_SET_FLAGS (button_widget, GTK_CAN_FOCUS); */
-
 	gtk_container_add (GTK_CONTAINER (button_item), GTK_WIDGET (button_widget));
 
 	set_image (button_item, pixbuf);
