@@ -15,13 +15,50 @@
 
 #include <bonobo/bonobo-ui-xml.h>
 #include <bonobo/bonobo-ui-util.h>
+#include <bonobo/bonobo-ui-toolbar-button-item.h>
 #include <bonobo/bonobo-window.h>
 
 #include <bonobo/bonobo-i18n.h>
 #include <bonobo/bonobo-ui-main.h>
 #include <bonobo/bonobo-ui-preferences.h>
 
-BonoboUIComponent *global_component;
+static const char * tame_xpm[] = {
+"24 24 8 1",
+"       c None",
+".      c #FFFFFF",
+"+      c #9E9E9E",
+"@      c #484848",
+"#      c #131313",
+"$      c #CFCFCF",
+"%      c #363636",
+"&      c #000000",
+"                        ",
+"                        ",
+"                        ",
+"                        ",
+"         .....          ",
+"       .........        ",
+"      ...+@#@+...       ",
+"     ..$%&&&&&%$..      ",
+"     ..%&&&&&&&%..      ",
+"    ..+&&&&&&&&&+..     ",
+"    ..@&&&&&&&&&@..     ",
+"    ..#&&&&&&&&&#..     ",
+"    ..@&&&&&&&&&@..     ",
+"    ..+&&&&&&&&&+..     ",
+"     ..%&&&&&&&%..      ",
+"     ..$%&&&&&%$..      ",
+"      ...+@#@+...       ",
+"       .........        ",
+"         .....          ",
+"                        ",
+"                        ",
+"                        ",
+"                        ",
+"                        "
+};
+
+static BonoboUIComponent *global_component;
 
 #define PRINT_PREF(spref, pref) \
 	fprintf (stderr, "\t" spref " : %s\n", \
@@ -122,7 +159,7 @@ toggled_cb (BonoboUIComponent           *component,
 	    const char                  *state,
 	    gpointer                     user_data)
 {
-	fprintf (stderr, "toggled to '%s' type '%d' path '%s'\n",
+	fprintf (stderr, "toggled to '%s' type '%u' path '%s'\n",
 		 state, type, path);
 }
 
@@ -184,7 +221,7 @@ do_sane_popup (GtkWidget      *widget,
 	return FALSE;
 }
 
-BonoboUIVerb verbs [] = {
+static BonoboUIVerb verbs [] = {
 	BONOBO_UI_VERB ("FileExit", file_exit_cmd),
 	BONOBO_UI_VERB ("FileOpen", file_open_cmd),
 
@@ -215,6 +252,10 @@ main (int argc, char **argv)
 		"		pixtype=\"stock\" pixname=\"Close\" accel=\"*Control*q\"/>\n"
 		"	</submenu>\n"
 		"</menu>";
+	char keysa [] =
+		"<keybindings>\n"
+		"   <accel name=\"*Control*3\" id=\"MyFoo\"/>\n"
+		"</keybindings>\n";
 	char simpleb [] =
 		"<submenu name=\"File\" _label=\"_File\">\n"
 		"	<menuitem name=\"open\" _label=\"_OpenB\" pixtype=\"stock\" pixname=\"Open\" _tip=\"Open you fool\"/>\n"
@@ -245,7 +286,9 @@ main (int argc, char **argv)
 		"	<separator/>\n"
 		"	<toolitem name=\"baa\" pixtype=\"stock\" pixname=\"Open\" _label=\"baa\" _tip=\"My 2nd tooltip\" verb=\"testme\"/>\n"
 		"	<control name=\"AControl\" _tip=\"a tip on a control\" hidden=\"0\" vdisplay=\"button\"\n"
-		"	pixtype=\"stock\" pixname=\"Attach\"/>\n"
+		"	pixtype=\"stock\" pixname=\"gtk-italic\" _label=\"EntryControl\" verb=\"OpenEntry\"/>\n"
+		"	<control name=\"BControl\" _tip=\"another tip on a control\" hidden=\"0\"\n"
+		"	pixtype=\"stock\" pixname=\"gtk-stop\"/>\n"
 		"</dockitem>";
 	char toolb [] =
 		"<dockitem name=\"Toolbar\" look=\"icon\" relief=\"none\">\n"
@@ -314,7 +357,7 @@ main (int argc, char **argv)
 		gtk_box_pack_start_defaults (GTK_BOX (box), button);
 
 		path_entry = gtk_entry_new ();
-		gtk_entry_set_text (GTK_ENTRY (path_entry), "/menu/File/toggle");
+		gtk_entry_set_text (GTK_ENTRY (path_entry), "/commands/MyFoo");
 		gtk_widget_show (GTK_WIDGET (path_entry));
 		gtk_box_pack_start_defaults (GTK_BOX (box), path_entry);
 
@@ -385,6 +428,9 @@ main (int argc, char **argv)
 	bonobo_ui_component_set_translate (componenta, "/popups/MyStuff", simpleb, ev);
 	g_assert (!BONOBO_EX (ev));
 
+	bonobo_ui_component_set_translate (componenta, "/", keysa, ev);
+	g_assert (!BONOBO_EX (ev));
+
 	bonobo_ui_component_set_translate (componentb, "/",   toola, ev);
 	g_assert (!BONOBO_EX (ev));
 
@@ -420,21 +466,6 @@ main (int argc, char **argv)
 						widget, ev);
 	}
 
-#ifdef OLD_STUFF
-	{
-		GtkWidget *widget = gtk_entry_new ();
-		BonoboControl *control = bonobo_control_new (widget);
-		
-		gtk_entry_set_text (GTK_ENTRY (widget), "Example text");
-		gtk_widget_show (widget);
-		bonobo_ui_component_object_set (componenta,
-						"/Toolbar/AControl",
-						BONOBO_OBJREF (control),
-						ev);
-		bonobo_object_unref (BONOBO_OBJECT (control));
-		g_assert (!BONOBO_EX (ev));
-	}
-#else
 	{
 		GtkWidget *widget = gtk_entry_new ();
 		
@@ -445,7 +476,16 @@ main (int argc, char **argv)
 						widget, ev);
 		g_assert (!BONOBO_EX (ev));
 	}
-#endif
+	{
+		GtkWidget *widget;
+		GdkPixbuf *pixbuf = gdk_pixbuf_new_from_xpm_data (tame_xpm);
+		widget = bonobo_ui_toolbar_button_item_new (pixbuf, "Test Control");
+		gtk_widget_show (widget);
+		bonobo_ui_component_widget_set (componenta,
+						"/Toolbar/BControl",
+						widget, ev);
+		g_assert (!BONOBO_EX (ev));
+	}
 
 	bonobo_ui_component_add_listener (componentb, "MyFoo", toggled_cb, ev);
 	g_assert (!BONOBO_EX (ev));
@@ -490,8 +530,9 @@ main (int argc, char **argv)
 	CORBA_exception_free (ev);
 
   	{
-  		char *txt = bonobo_ui_component_get (componenta, "/status/main", TRUE, NULL);
  		const char *good = "<item name=\"main\">WhatA6&gt;</item>\n";
+
+  		txt = bonobo_ui_component_get (componenta, "/status/main", TRUE, NULL);
  
  		if (!txt || strcmp (txt, good)) {
  			g_warning ("Broken merging code '%s' should be '%s'", txt, good);
